/**
 * Cordova原生代码与JS文件接口
 * 原生代码实现接口时需要注意：
 *	1. 服务实现时错误处理需要统一处理，并将提示信息返回给错误处理函数
 *	2. 如果没有参数，则需要[]结束
 *	3. 要调用的方法，必须要和后台的方法名一致
 */
var RuixinApi = function() {
};

/*
 * 原生代码识别URI
 */
RuixinApi.prototype.uri ='imwebviewjs::';


/*RuixinApi.prototype.config = function(params)
{
	return this;
};*/

RuixinApi.prototype.callNative = function(funcName, params) {
	var url = this.uri + funcName + this.commonProcess(params);
	document.location = url;
};

/**
 * 初始化js框架
 * @param appId 必填，公众号的唯一标识
 * @param accessToken 必填，开发者接口调用凭证
 * @param success 成功时的回调函数名称
 * @param fail 失败时的回调函数名称
 */
RuixinApi.prototype.config =  function(params) {
    this.callNative("config", params);
};

/**
 * 获取已经登录用户的相关信息
 * @param success 成功时的回调函数名称!!注意一定是名称
 */
RuixinApi.prototype.getUserInfo = function(params) {
	this.callNative("getUserInfo", params);
};

/**
 * 文档预览
 * @param fileUrl文件下载地址
 * @param fileName文件名称
 */
RuixinApi.prototype.docPreview = function(params) {
	this.callNative("docPreview", params);
};

/**
 * 修改页面标题
 * @param success 成功时的回调函数名称
 */
RuixinApi.prototype.setWebViewTitle =  function(params) {
	this.callNative("setWebViewTitle", params);
};

/**
 * 隐藏页面标题
 * @param success 成功时的回调函数名称
 */
RuixinApi.prototype.hideWebViewTitle =  function(params) {
	this.callNative("hideWebViewTitle", params);
};

/**
 * 查看人员详情
 * @param userEmail 查看人员的邮箱
 * @param success 成功时的回调函数名称
 * @param fail 无权限时的回调函数名称
 */
RuixinApi.prototype.showUserInfo =  function(params) {
	this.callNative("showUserInfo", params);
};

/**
 * 向内网服务器发送get请求
 * @param url 请求内网地址+URLEncode后的参数
 * @param success 成功时的回调函数名称
 * @param fail 失败时的回调函数名称
 */
RuixinApi.prototype.get =  function(params) {
	this.callNative("get", params);
};

/**
 * 向内网服务器发送post请求
 * @param url  请求内网地址
 * @param params {post参数表}
 * @param body post内容
 * @param success 成功时的回调函数名称
 * @param fail 失败时的回调函数名称
 */
RuixinApi.prototype.post =  function(params) {
	this.callNative("post", params);
};

/**
 * 隐藏分享按钮
 * @param success 成功时的回调函数名称
 */
RuixinApi.prototype.hideShareButton =  function(params) {
	this.callNative("hideShareButton", params);
};

/**
 * 返回上一级页面
 * @param success 成功时的回调函数名称
 */
RuixinApi.prototype.goBackPreviousPage =  function(params) {
	this.callNative("goBackPreviousPage", params);
};

/**
 * 关闭当前页
 * @param success 成功时的回调函数名称
 */
RuixinApi.prototype.closePage =  function(params) {
	this.callNative("closePage", params);
};

/**
 * 通用参数处理，用于将json参数转换为uri的参数
 */
RuixinApi.prototype.commonProcess = function(params) {
	if (this.isEmpty(params))
	{
		return "";
	}
	if (this.isString(params))
	{
		return "&" + params;
	} else {
		return "&" + JSON.stringify(params);
	}
}

/**
 * 判断是否非空
 */
RuixinApi.prototype.isEmpty = function(callbackName)
{
	if (callbackName!=null && !callbackName && typeof(callbackName)!="undefined" && callbackName!=0)
	{
		return true;
	}
	return false;
}

/**
 * 判断是否字符串
 */
RuixinApi.prototype.isString = function(str)
{ 
	return (typeof str=='string')&&str.constructor==String; 
}