/**
 * Cordova原生代码与JS文件接口
 * 原生代码实现接口时需要注意：
 *	1. 服务实现时错误处理需要统一处理，并将提示信息返回给错误处理函数
 *	2. 如果没有参数，则需要[]结束
 *	3. 要调用的方法，必须要和后台的方法名一致
 */
var funcData = {};
var UmappPlugin = function() {


};

/*
 * js版本号
 */
UmappPlugin.prototype.versionNumber = function() {
    return 10000;
};

/*
 * 原生代码服务名称
 */
UmappPlugin.prototype.service ='UmappPlugin';
UmappPlugin.prototype.uri ='imwebviewjs::';

Function.prototype.getName = function(){
	var fnName = this.toString();
	fnName = fnName.substr(0, fnName.indexOf('('));
	fnName = fnName.replace(/^function/, '');
	return fnName.replace(/(^\s+)|(\s+$)/g, '');
}
/**
*  引用插件
*/
UmappPlugin.prototype.exec = function(success, fail, service, funcName, paramArray)
{
	var callId = generateMixed(16);
	var funcDataDetail = {"callId":callId,"success":success,"error":fail,"service":service,"funcName":funcName,"paramArray":paramArray};
	funcData[callId] = funcDataDetail;
	var param = paramArray[0];
    if (param == undefined){
        param = {};
    }
	param.success = "UmappPluginCommonSuccess";
	param.error = "UmappPluginCommonError";
    param.callId = callId;
	var url = this.uri + funcName + this.commonProcess(param);
    //alert(url);
    url=encodeURI(url);
//	document.location = url;
	// 创建一个iframe用于加载url
	var iframe = document.createElement("iframe");
	iframe.style.display = "none";
	iframe.src = url;
    iframe.onload = function(state){
	    try {
			// 加载成功后移除iframe
		    iframe.parentNode.removeChild(iframe);
		} catch (error) {}
	};
	document.documentElement.appendChild(iframe);
}

/**
 * 通用参数处理，用于将json参数转换为uri的参数
 */
UmappPlugin.prototype.commonProcess = function(params) {
	if (this.isEmpty(params))
	{
		return "";
	}
	if (this.isString(params))
	{
		return "&" + params;
	} else {
		return "&" + JSON.stringify(params);
	}
}

/**
 * 判断是否非空
 */
UmappPlugin.prototype.isEmpty = function(callbackName)
{
	if (callbackName!=null && !callbackName && typeof(callbackName)!="undefined" && callbackName!=0)
	{
		return true;
	}
	return false;
}

/**
 * 判断是否字符串
 */
UmappPlugin.prototype.isString = function(str)
{ 
	return (typeof str=='string')&&str.constructor==String; 
}

/**
 * 弹出对话框，该方法需要同步弹出对话框，并在关闭对话框后调用相应的回调函数
 * @param success 方法执行成功的回调函数
 * @param error 方法执行失败的回调函数
 * @param params
 * 		参数数组，按照顺序为：
 *			提示信息(字符串),
 *			弹出框类型(整型,1表示有确定按钮，3表示有确定和取消两个按钮，默认为1),
 *			标题(字符串，默认为空),确定按钮文字(字符串，默认为确定),取消按钮文字(字符串，默认为取消),
 *			确定回调函数，取消回调函数
 */
window.showDialog = function(success, error, params) {
    alert(params[0]);
    success();
};

/**
 * 通用成功方法，空方法
 * @param params 原生代码返回参数
 */
window.commonSuccess = function(params) {
	loadStop();
};


/**
 * 通用错误方法，弹出提示信息
 * @param msg 原生代码返回错误信息
 */
window.commonError = function(msg)
{
	if (msg == 2)
	{
		showDialog(commonSuccess, commonSuccess, ["没有找到类"]);
	} else if (msg == 3)
	{
		showDialog(commonSuccess, commonSuccess, ["错误的引用"]);
	} else if (msg == 4)
	{
		showDialog(commonSuccess, commonSuccess, ["实例化失败"]);
	} else if (msg == 5)
	{
		showDialog(commonSuccess, commonSuccess, ["错误的URL"]);
	} else if (msg == 6)
	{
		showDialog(commonSuccess, commonSuccess, ["IO错误"]);
	} else if (msg == 7)
	{
		showDialog(commonSuccess, commonSuccess, ["没有找到方法"]);
	} else if (msg == 8)
	{
		showDialog(commonSuccess, commonSuccess, ["JSON格式错误"]);
	} else if (msg == 9)
	{
		showDialog(commonSuccess, commonSuccess, ["其它错误"]);
	} else {
		//showDialog(commonSuccess, commonSuccess, [msg]);
	}
};



/**
 * 获取全局、页面、流程、协议jsonObject对象
 * 需要发送协议内容至服务端(详见UmappPlugin.java->getAllVariate) 
 * @param success 成功时的回调函数
 * @param params  协议的参数
 */
UmappPlugin.prototype.getAllVariate =  function(success,params) {
	this.exec(success, commonError, this.service, "getAllVariate", [params]);
};


/**
 * 更新审批建议(瑞飞oa)
 * 表单序列化后，发送协议至服务端(详见UmappPlugin.java->updateSuggestionForPass) 
 * @param success 成功时的回调函数，该函数通过服务器返回的数据判断是否需要选择审批人员界面
 */
UmappPlugin.prototype.updateSuggestionForPass =  function(success) {
	var  params=$("#pageForm").serializeJson();
    this.exec(success, commonError, this.service, "updateSuggestionForPass", [params]);
};


/**
 * 更新审批建议回调函数(瑞飞oa)
 * 更新完审批建议后，通过服务器返回的json数据，判断是否需要打开选择人员界面
 * @param params 更新建议后服务器返回的json数据
 */
UmappPlugin.prototype.suggestionPlugin =  function(params) {
    this.exec(commonSuccess, commonError, this.service, "suggestionPlugin", [params]);
};



/**
 * 工单审核不通过
 * 表单序列化后，发送协议至服务端(详见UmappPlugin.java->authBacklogBack) 
 * @param success 成功时的回调函数
 */
UmappPlugin.prototype.authBacklogBack =  function(success) {
	var  params=$("#pageForm").serializeJson();
    this.exec(success, commonError, this.service, "authBacklogBack", [params]);
};

/**
 * 关闭工单详情页面
 * 该方法为当表单通过或驳回后，执行的回调函数，关闭详情页面(详见UmappPlugin.java->closeDetail) 
 * @param params 通过或者驳回后返回的json数据
 */
UmappPlugin.prototype.closeDetail =  function(params) {
    this.exec(commonSuccess, commonError, this.service, "closeDetail", [params]);
};

/**
 * 关闭旋转进度条
 */
UmappPlugin.prototype.closeProgressBar =  function() {
    this.exec(commonSuccess, commonError, this.service, "closeProgressBar", []);
};

/**
 * 下载审批附件
 * @param params 该附件属性的jsonObject
 */
UmappPlugin.prototype.downloadAttachment =  function(params) {
    this.exec(commonSuccess, commonError, this.service, "downloadAttachment", [params]);
};

/**
 * 显示Android原生对话框，(暂未使用)
 * @param params 显示的文字
 */
UmappPlugin.prototype.showAndroidDialog =  function(params) {
    this.exec(commonSuccess, commonError, this.service, "showAndroidDialog", [params]);
};
/**
 * 跳转页面
 * @param params 页面的地址
 */
UmappPlugin.prototype.jumpPage =  function(params) {
    this.exec(commonSuccess, commonError, this.service, "jumpPage", [params]);
};

/**
 * 返回到待办页面（刷新）
 */
UmappPlugin.prototype.returnBacklog =  function(params) {
    this.exec(commonSuccess, commonError, this.service, "returnBacklog", [params]);
};


/**
 * 返回到待办页面（不刷新）
 */
UmappPlugin.prototype.returnBacklogNoRefresh =  function() {
    this.exec(commonSuccess, commonError, this.service, "returnBacklogNoRefresh", []);
};

/**
 * 返回到详情页面
 */
UmappPlugin.prototype.returnDetail =  function() {
    this.exec(commonSuccess, commonError, this.service, "returnDetail", []);
};

/**
 * 关闭当前页面
 */
UmappPlugin.prototype.closePage =  function() {
    this.exec(commonSuccess, commonError, this.service, "closePage", []);
};



/**
 * 替换json
 * @param success  回调函数
 * @param original 原始的json
 * @param destination  要替换的json  key  value 
 */
UmappPlugin.prototype.replaceJson =  function(success,original,destination) {
    this.exec(success, commonError, this.service, "replaceJson", [{
			"original":original,
			"destination":destination
		}]);
};

/**
 * 提交数据 
 * @param success 成功时的回调函数
 * @param params  body里的json数据
 */
UmappPlugin.prototype.submitData =  function(success,params) {
    this.exec(success, commonError, this.service, "submitData", [params]);
};

/**
 * 获得人员的信息
 * @param success 成功时的回调函数
 * @param params  body里的json数据
 */
UmappPlugin.prototype.getUserInfo =  function(params) {
    this.exec(commonSuccess, commonError, this.service, "getUserInfo", [params]);
};


/**
 * 工单审核通过，(暂未使用)
 * @param success 成功时的回调函数，空函数
 */
UmappPlugin.prototype.authBacklogPass =  function(success) {
	var  params=$("#pageForm").serializeJson();
    this.exec(success, commonError, this.service, "authBacklogPass", [params]);
};


/**
 * 设置全局变量(暂未用到，后期优化可能用到)
 * @param key 	 添加配置的键名	
 * @param value  添加配置的对象
 */
/*UmappPlugin.prototype.setGlobalParam = function(key,value) {
    this.exec(commonSuccess, commonError, this.service, "setGlobalParam",  [{
		"key":key,
		"value":value
	}]);
};*/

/**
 * 获取全部全局变量(暂未用到，后期优化可能用到)
 * @param success 成功时的回调函数，参数为全部全局变量(JSON格式)
 */
/*UmappPlugin.prototype.getGlobalParams = function(success) {
    this.exec(success, commonError, this.service, "getGlobalParams", []);
};*/

/**
 * 清空全局变量(暂未用到，后期优化可能用到)
 */
/*UmappPlugin.prototype.clearGlobalParams = function() {
    this.exec(commonSuccess, commonError, this.service, "clearGlobalParams", []);
};*/


/**
 * 设置流程变量(暂未用到，后期优化可能用到)
 * @param key 	 添加配置的键名	
 * @param value  添加配置的对象
 */
/*UmappPlugin.prototype.setFlowParam = function(key,value) {
    this.exec(commonSuccess, commonError, this.service, "setFlowParam",  [{
		"key":key,
		"value":value
	}]);
};*/




/**
 * 获取全部流程变量
 * @param success 成功时的回调函数，参数为全部流程变量(JSON格式)
 */
UmappPlugin.prototype.getFlowParams = function(success) {
    this.exec(success, commonError, this.service, "getFlowParams", []);
};

/**
 * 清空流程变量(暂未用到，后期优化可能用到)
 */
/*UmappPlugin.prototype.clearFlowParams = function() {
    this.exec(commonSuccess, commonError, this.service, "clearFlowParams", []);
};*/



/**
 * 设置页面配置变量(暂未用到，后期优化可能用到)
 * @param key 	 添加配置的键名	
 * @param value  添加配置的对象
 */
/*UmappPlugin.prototype.setPageParam = function(key,value) {
    this.exec(commonSuccess, commonError, this.service, "setPageParam", [{
		"key":key,
		"value":value
	}]);
};*/

/**
 * 获取全部页面配置变量(暂未用到，后期优化可能用到)
 * @param success 成功时的回调函数，参数为全部页面变量(JSON格式)
 */
/*UmappPlugin.prototype.getPageParams = function(success) {
    this.exec(success, commonError, this.service, "getPageParams", []);
};*/
/**
 * 清空页面变量(暂未用到，后期优化可能用到)
 */
/*UmappPlugin.prototype.clearPageParams = function() {
    this.exec(commonSuccess, commonError, this.service, "clearPageParams", []);
};*/

/**
 * 显示提示框
 */
UmappPlugin.prototype.showAlert = function(msg) {
    this.exec(commonSuccess, commonError, this.service, "showAlert", [{"msg":msg}]);
};

/**
 * 显示等待框
 */
UmappPlugin.prototype.showProgressBar = function() {
    this.exec(commonSuccess, commonError, this.service, "showProgressBar", []);
};

/**
 * 文档预览
 * @param AttachWholeUrl 	 附件的完整路径:该路径中如果有参数，参数不用Encode
 * @param AttachName         附件名称带扩展名
 */
UmappPlugin.prototype.docPreview = function(params) {
    this.exec(commonSuccess, commonError, this.service, "docPreview", [params]);
};

/**
 * 屏蔽android的物理返回键
 * @param neglectAndroidBack 	 boolean   true代表屏蔽，false代表不屏蔽
 */
UmappPlugin.prototype.neglectAndroidPhysicalBack = function(params) {
    this.exec(commonSuccess, commonError, this.service, "neglectAndroidPhysicalBack", [params]);
};


var chars = ['0','1','2','3','4','5','6','7','8','9','A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'];

function generateMixed(n) {
     var res = "";
     for(var i = 0; i < n ; i ++) {
         var id = Math.ceil(Math.random()*35);
         res += chars[id];
     }
     return res;
}

function UmappPluginCommonSuccess(res)
{
    //alert(res.callId);
    //alert(JSON.stringify(funcData));
	if (res.callId != undefined)
	{
		funcDataDetail = funcData[res.callId];
        funcData[res.callId] = undefined;
		if (funcDataDetail.success != undefined)
		{
			funcDataDetail.success(res);
		}
	}
}
function UmappPluginCommonError(res)
{
	if (res.callId != undefined)
	{
		funcDataDetail = funcData[res.callId];
        funcData[res.callId] = undefined;
		if (funcDataDetail.error != undefined)
		{
			funcDataDetail.error(res);
		}
	}
}